package javax.swing.event;

import javax.swing.tree.TreePath;
import java.util.EventObject;

public class TreeSelectionEvent extends EventObject
{
    protected TreePath[] paths;
    protected boolean[] areNew;
    protected TreePath oldLeadSelectionPath;
    protected TreePath newLeadSelectionPath;
    
    public TreeSelectionEvent(Object source, TreePath[] paths, boolean[] areNew, TreePath oldLeadSelectionPath, TreePath newLeadSelectionPath) {
        super(source);
        this.paths = paths;
        this.areNew = areNew;
        this.oldLeadSelectionPath = oldLeadSelectionPath;
        this.newLeadSelectionPath = newLeadSelectionPath;
    }
    
    public TreeSelectionEvent(Object source, TreePath treePath, boolean b, TreePath oldLeadSelectionPath, TreePath newLeadSelectionPath) {
        super(source);
        (this.paths = new TreePath[1])[0] = treePath;
        (this.areNew = new boolean[1])[0] = b;
        this.oldLeadSelectionPath = oldLeadSelectionPath;
        this.newLeadSelectionPath = newLeadSelectionPath;
    }
    
    public TreePath[] getPaths() {
        int length = this.paths.length;
        TreePath[] array = new TreePath[length];
        System.arraycopy(this.paths, 0, array, 0, length);
        return array;
    }
    
    public TreePath getPath() {
        return this.paths[0];
    }
    
    public boolean isAddedPath() {
        return this.areNew[0];
    }
    
    public boolean isAddedPath(TreePath o) {
        int i = this.paths.length - 1;
        while (i >= 0) {
            if (this.paths[i].equals(o)) {
                return this.areNew[i];
            }
            --i;
        }
        throw new IllegalArgumentException("path is not a path identified by the TreeSelectionEvent");
    }
    
    public boolean isAddedPath(int n) {
        if (this.paths == null || n < 0 || n >= this.paths.length) {
            throw new IllegalArgumentException("index is beyond range of added paths identified by TreeSelectionEvent");
        }
        return this.areNew[n];
    }
    
    public TreePath getOldLeadSelectionPath() {
        return this.oldLeadSelectionPath;
    }
    
    public TreePath getNewLeadSelectionPath() {
        return this.newLeadSelectionPath;
    }
    
    public Object cloneWithSource(Object o) {
        return new TreeSelectionEvent(o, this.paths, this.areNew, this.oldLeadSelectionPath, this.newLeadSelectionPath);
    }
}
